@@ -2,7 +2,7 @@
 
 """
 @author: Ivano Lauriola
-@email: ivano.lauriola@phd.unipd.it
+@email: ivano.lauriola@phd.unipd.it, ivanolauriola@gmail.com
 
 This file is part of MKLpy: a scikit-compliant framework for Multiple Kernel Learning
 This file is distributed with the GNU General Public License v3 <http://www.gnu.org/licenses/>.  
@@ -10,19 +10,13 @@ This file is distributed with the GNU General Public License v3 <http://www.gnu.
 """
 
 
-from .base import MKL
+from .base import MKL, OneStepMKL, TwoStepMKL, Cache, Solution
 from .AverageMKL import AverageMKL
 from .EasyMKL import EasyMKL
 from .GRAM import GRAM
 from .komd import KOMD
 from .MEMO import MEMO
-
-__all__ = [
-    'AlternateMKL',
-    'AverageMKL',
-    'MKL',
-    'EasyMKL',
-    'GRAM',
-    'KOMD',
-    'MEMO',
-]
+#from .SimpleMKL import SimpleMKL	available soon
+from .RMKL import RMKL
+from .HeuristicMKL import HeuristicMKL, PWMK, FHeuristic
+from .CKA import CKA
