@@ -1,22 +1,22 @@
+# -*- coding: latin-1 -*-
+
 """
-.. codeauthor:: Ivano Lauriola <ivanolauriola@gmail.com>
+@author: Ivano Lauriola
+@email: ivano.lauriola@phd.unipd.it, ivanolauriola@gmail.com
 
-==================
-Regularize Kernels
-==================
-
-.. currentmodule:: MKLpy.regularization
-
-This module contains function that perform a transformation over kernels and samples matrices
+This file is part of MKLpy: a scikit-compliant framework for Multiple Kernel Learning
+This file is distributed with the GNU General Public License v3 <http://www.gnu.org/licenses/>.  
 
 """
 
 import numpy as np
+import torch
 from ..metrics import trace
 from ..utils.validation import check_K
 
 
 
+
 def kernel_normalization(K):
     """normalize a squared kernel matrix
 
@@ -40,9 +40,15 @@ def kernel_normalization(K):
     K   = check_K(K)
     n = K.size()[0]
     d = K.diag().view(n,1)
-    return K / (d @ d.T)**0.5
+    K /= (d @ d.T)**0.5
+    K[K!=K] = 0
+    return K
     
 
+
+
+
+
 def tracenorm(K):
     """normalize the trace of a squared kernel matrix
 
@@ -81,6 +87,6 @@ def kernel_centering(K):
     """
     K = check_K(K)
     N = K.size()[0]
-    I = torch.ones(K.size())
+    I = torch.ones(K.size()).double()
     C = torch.ones(N).diag() - (1.0/N * I)
     return C @ K @ C
