@@ -1,3 +1,14 @@
+# -*- coding: latin-1 -*-
+
+"""
+@author: Ivano Lauriola
+@email: ivano.lauriola@phd.unipd.it, ivanolauriola@gmail.com
+
+This file is part of MKLpy: a scikit-compliant framework for Multiple Kernel Learning
+This file is distributed with the GNU General Public License v3 <http://www.gnu.org/licenses/>.  
+
+"""
+
 import numpy as np
 from sklearn.metrics import roc_auc_score, accuracy_score
 import warnings
@@ -14,7 +25,10 @@ class Scheduler():
 		self.model = model
 
 	def step(self, i, delta):
+		'''checks the improvemen and adjusts, in case, the learning rate
+			returns True if the convergence is reached'''
 		raise NotImplementedError("This is an abstract method")
+	
 
 
 
@@ -27,11 +41,9 @@ class ReduceOnWorsening(Scheduler):
 
 
 	def step(self, i, delta):
+
 		if delta < 0:
 			self.model.learning_rate *= self.multiplier
-			#print ('[%d][scheduler] %f improv. learning rate set to' % (i,delta), self.model.learning_rate)
-		if self.model.learning_rate < self.min_lr:
-			self.model.convergence = True
-			#print ('[%d][scheduler] min lr, convergence is reached' % i)
+		return self.model.learning_rate < self.min_lr
 
 
